<?php

use Google\Spreadsheet\DefaultServiceRequest;
use Google\Spreadsheet\ServiceRequestFactory;

class Gsheet extends MY_Controller {

    public $google_client;
    public $accessToken;
    public $serviceRequest;
    public $spreadsheetService;
    public $spreadsheetFeed;
    public $currentSpreadSheet;
    public $worksheetFeed;

    public function __construct() {
        parent::__construct();
        try{
        $this->google_client = new Google_Client();
        $this->google_client->setClientId($this->google_sheet->ClientID());
        $this->google_client->setClientSecret($this->google_sheet->ClientSecret());
        $this->google_client->setRedirectUri($this->google_sheet->RedirectURI());
        $this->google_client->setScopes(array('https://spreadsheets.google.com/feeds'));
        //https://developers.google.com/identity/protocols/OAuth2WebServer?hl=en
        $this->google_client->setAccessType("offline");
        if (isset($_SESSION['token'])) { // extract token from session and configure client
            $this->google_client->setAccessToken($_SESSION['token']);
        }
        if (!$this->google_client->getAccessToken()) {
            redirect("welcome/index");
        }

        $this->accessToken = json_decode($this->google_client->getAccessToken());

        $this->serviceRequest = new DefaultServiceRequest($this->accessToken->access_token);
        ServiceRequestFactory::setInstance($this->serviceRequest);
        $this->spreadsheetService = new Google\Spreadsheet\SpreadsheetService();
        $this->spreadsheetFeed = $this->spreadsheetService->getSpreadsheets();
        $this->currentSpreadSheet = $this->spreadsheetFeed->getByTitle("Inventory ReOrder Database");
        $this->worksheetFeed = $this->currentSpreadSheet->getWorksheets();
        }catch(Exception $ex){
            $this->session->sess_destroy();
            redirect("welcome/index");
        }
        //print_r($this->worksheetFeed);
    }

    public function index() {
        $this->map("worksheetFeed", $this->worksheetFeed);
        $this->load->view('layout/header', $this->data);
        $this->load->view('gsheet/index', $this->data);
        $this->load->view('layout/footer', $this->data);
    }

}
