<?php

//ini_set("display_errors", "on");
use Google\Spreadsheet\DefaultServiceRequest;
use Google\Spreadsheet\ServiceRequestFactory;

class Sync extends MY_Controller {

    public $google_client;
    public $accessToken;
    public $serviceRequest;
    public $spreadsheetService;
    public $spreadsheetFeed;
    public $currentSpreadSheet;
    public $worksheetFeed;

    public function __construct() {
        parent::__construct();
        try {
            $this->google_client = new Google_Client();
            $this->google_client->setClientId($this->google_sheet->ClientID());
            $this->google_client->setClientSecret($this->google_sheet->ClientSecret());
            $this->google_client->setRedirectUri($this->google_sheet->RedirectURI());
            $this->google_client->setScopes(
                    array(
                        'https://www.googleapis.com/auth/userinfo.email',
                        'https://www.googleapis.com/auth/userinfo.profile',
                        'https://spreadsheets.google.com/feeds'));
            $this->google_client->setAccessType("offline");
            $this->google_client->setApprovalPrompt("auto");

            $this->google_plus = new Google_Oauth2Service($this->google_client);
            if (isset($_SESSION['token'])) { // extract token from session and configure client
                $this->google_client->setAccessToken($_SESSION['token']);
            }

            if (!$this->google_client->getAccessToken()) {
                redirect("welcome/index");
            }
            if ($this->google_client->isAccessTokenExpired()) {
                if (isset($_SESSION['refresh_token'])) {
                    $this->google_client->refreshToken($_SESSION['refresh_token']);
                    $_SESSION['token'] = $this->google_client->getAccessToken();
                }
            }
            //$google_token = json_decode($_SESSION['token']);
            //print_r($google_token);
            // $this->google_client->refreshToken($google_token->refresh_token);
            // $_SESSION['token'] = $this->google_client->getAccessToken();
            $this->accessToken = json_decode($this->google_client->getAccessToken());
            $this->serviceRequest = new DefaultServiceRequest($this->accessToken->access_token);
            ServiceRequestFactory::setInstance($this->serviceRequest);
            $this->spreadsheetService = new Google\Spreadsheet\SpreadsheetService();
            $this->spreadsheetFeed = $this->spreadsheetService->getSpreadsheets();
            $this->currentSpreadSheet = $this->spreadsheetFeed->getByTitle("Inventory ReOrder Database");
            $this->worksheetFeed = $this->currentSpreadSheet->getWorksheets();
        } catch (Exception $ex) {
            //print_r($ex);
            $this->session->sess_destroy();
            redirect("welcome/index");
        }
    }

    public function sync_mapping_and_descriptions() {

        $this->mapping_and_descriptions_model->DeleteAll();
        $worksheet = $this->worksheetFeed->getByTitle('Mapping and Descriptions');
        $listFeed = $worksheet->getListFeed();
        foreach ($listFeed->getEntries() as $entry) {
            $values = $entry->getValues();
            $object = json_decode(json_encode($values), FALSE);
            $object->_username = isset($_SESSION['userinfo']['email']) ? $_SESSION['userinfo']['email'] : "";
            $this->mapping_and_descriptions_model->Create($object);
        }
        $last_update_model = new Last_update_model();
        $last_update_model->_username = isset($_SESSION['userinfo']['email']) ? $_SESSION['userinfo']['email'] : "";
        $last_update_model->table_name = 'mapping_and_descriptions';
        $last_update_model->dt = date("Y-m-d h:i:s");
        $this->last_update_model->Create($last_update_model);
        redirect("sync/mapping_and_descriptions");
    }

    public function mapping_and_descriptions() {
        $this->map("list", $this->mapping_and_descriptions_model->Read());
        $this->map("cols", $this->mapping_and_descriptions_model->cols);
        $dt = $this->last_update_model->LastDt(isset($_SESSION['userinfo']['email']) ? $_SESSION['userinfo']['email'] : "", 'mapping_and_descriptions');
        $this->map("dt", $dt);
        $this->load->view($this->header(), $this->data);
        $this->render("layout/global_header");
        $this->render();
        $this->render("layout/global_footer");
        $this->load->view($this->footer(), $this->data);
    }

    public function sync_manual_product_data() {
        $this->manual_product_data_model->DeleteAll();
        $worksheet = $this->worksheetFeed->getByTitle('Manual Product Data');
        $listFeed = $worksheet->getListFeed();
        foreach ($listFeed->getEntries() as $entry) {
            $values = $entry->getValues();
            $values['notesproduct'] = $values['notes-product'];
            $values['notespackaging'] = $values['notes-packaging'];
            $values['notescartons'] = $values['notes-cartons'];
            $values['notesmarks'] = $values['notes-marks'];
            $values['notesqc'] = $values['notes-qc'];
            $values['notesbrand'] = $values['notes-brand'];

            $object = json_decode(json_encode($values), FALSE);

            $object->_username = isset($_SESSION['userinfo']['email']) ? $_SESSION['userinfo']['email'] : "";
            $this->manual_product_data_model->Create($object);
        }
        $last_update_model = new Last_update_model();
        $last_update_model->_username = isset($_SESSION['userinfo']['email']) ? $_SESSION['userinfo']['email'] : "";
        $last_update_model->table_name = 'manual_product_data';
        $last_update_model->dt = date("Y-m-d h:i:s");
        $this->last_update_model->Create($last_update_model);
        $this->cron_util->GeneratedReorder_refresh();
        redirect("sync/manual_product_data");
    }

    public function sync_generate_order_display() {
        $this->generate_order_display_model->DeleteAll();
        $worksheet = $this->worksheetFeed->getByTitle('Generate Order-DISPLAY');
        $listFeed = $worksheet->getListFeed();
        foreach ($listFeed->getEntries() as $entry) {
            $values = $entry->getValues();
            $object = json_decode(json_encode($values), FALSE);
            $this->generate_order_display_model->Create($object);
        }
        $last_update_model = new Last_update_model();
        // $last_update_model->_username = $_SESSION['userinfo']['email'];
        $last_update_model->table_name = 'generate_order_display';
        $last_update_model->dt = date("Y-m-d h:i:s");
        $this->last_update_model->Create($last_update_model);
        redirect("sync/generate_order_display");
    }

    public function generate_order_display() {
        $this->map("list", $this->generate_order_display_model->Read());
        $this->map("cols", $this->generate_order_display_model->cols);
        $dt = $this->last_update_model->LastDt_('generate_order_display');
        $this->map("dt", $dt);
        $this->load->view($this->header(), $this->data);
        $this->render("layout/global_header");
        $this->render();
        $this->render("layout/global_footer");
        $this->load->view($this->footer(), $this->data);
    }

    public function manual_product_data() {
        $this->map("list", $this->manual_product_data_model->Read());
        $this->map("cols", $this->manual_product_data_model->cols);
        $dt = $this->last_update_model->LastDt($_SESSION['userinfo']['email'], 'manual_product_data');
        $this->map("dt", $dt);
        $this->load->view($this->header(), $this->data);
        $this->render("layout/global_header");
        $this->render();
        $this->render("layout/global_footer");
        $this->load->view($this->footer(), $this->data);
    }

    public function sync_manual_supplier_data() {
        $this->manual_supplier_data_model->DeleteAll();
        $worksheet = $this->worksheetFeed->getByTitle('Manual Supplier Data');
        $listFeed = $worksheet->getListFeed();
        foreach ($listFeed->getEntries() as $entry) {
            $values = $entry->getValues();
            $supleadtime = $values['sup.leadtime'];
            $supdaystostock = $values['sup.daystostock'];
            unset($values['sup.leadtime']);
            unset($values['sup.daystostock']);
            $object = json_decode(json_encode($values), FALSE);
            $object->supleadtime = $supleadtime;
            $object->supdaystostock = $supdaystostock;
            $object->_username = isset($_SESSION['userinfo']['email']) ? $_SESSION['userinfo']['email'] : "";
            $this->manual_supplier_data_model->Create($object);
        }
        $last_update_model = new Last_update_model();
        $last_update_model->_username = isset($_SESSION['userinfo']['email']) ? $_SESSION['userinfo']['email'] : "";
        $last_update_model->table_name = 'manual_supplier_data';
        $last_update_model->dt = date("Y-m-d h:i:s");
        $this->last_update_model->Create($last_update_model);
        $this->cron_util->GeneratedReorder_refresh("yes");
        redirect("sync/manual_supplier_data");
    }

    public function manual_supplier_data() {
        $this->map("list", $this->manual_supplier_data_model->Read());
        $this->map("cols", $this->manual_supplier_data_model->cols);
        $dt = $this->last_update_model->LastDt(isset($_SESSION['userinfo']['email']) ? $_SESSION['userinfo']['email'] : "", 'manual_supplier_data');
        $this->map("dt", $dt);
        $this->load->view($this->header(), $this->data);
        $this->render("layout/global_header");
        $this->render();
        $this->render("layout/global_footer");
        $this->load->view($this->footer(), $this->data);
    }

    public function sync_reorder_display() {

        $this->reorder_display_model->DeleteAll();
        $worksheet = $this->worksheetFeed->getByTitle('ReOrder-DISPLAY');

        $listFeed = $worksheet->getListFeed();
        foreach ($listFeed->getEntries() as $entry) {
            $values = $entry->getValues();
            $object = json_decode(json_encode($values), FALSE);
            $object->_username = isset($_SESSION['userinfo']['email']) ? $_SESSION['userinfo']['email'] : "";
            $this->reorder_display_model->Create($object);
        }
        $last_update_model = new Last_update_model();
        $last_update_model->_username = isset($_SESSION['userinfo']['email']) ? $_SESSION['userinfo']['email'] : "";
        $last_update_model->table_name = 'reorder_display';
        $last_update_model->dt = date("Y-m-d h:i:s");
        $this->last_update_model->Create($last_update_model);
        redirect("sync/reorder_display");
    }

    public function reorder_display() {
        $this->map("list", $this->reorder_display_model->Read());
        $this->map("cols", $this->reorder_display_model->cols);
        $dt = $this->last_update_model->LastDt(isset($_SESSION['userinfo']['email']) ? $_SESSION['userinfo']['email'] : "", 'reorder_display');
        $this->map("dt", $dt);
        $this->load->view($this->header(), $this->data);
        $this->render("layout/global_header");
        $this->render();
        $this->render("layout/global_footer");
        $this->load->view($this->footer(), $this->data);
    }

}
